==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/modules/sieve/language/cs.php <==
<?php


$l["name"]= 'Sieve';
$l["scriptname"]= 'Jméno skriptu';
$l["index"]= 'Index';
$l["test"]= 'Test';
$l["not"]= 'Není';
$l["type"]= 'Typ';
$l["arg"]= 'Argument';
$l["arg1"]= 'Argument1';
$l["arg2"]= 'Argument2';
$l["copy"]= 'Kopie';
$l["target"]= 'Cíl';
$l["sieverules"]= 'Pravidla';
$l["activatedrules"]= 'Aktivní pravidla';
$l["field"]= 'Pole';
$l["operator"]= 'Operátor';
$l["rules"]= 'Zpráva';
$l["actions"]= 'Akce';
$l["editsieve"]= 'Edituj pravidlo';
$l["action"]= 'Akce';
$l["ruletext"]= 'Pro příchozí zprávy';
$l["actiontext"]= '...vykonej následující akce';
$l["clear"]= 'Vyčisti';
$l["active"]= 'Aktivuj';
$l["activate"]= 'Aktivuj sadu filtrů';
$l["filterset"]= 'Sada filtrů:';
$l["days"]= 'Odpověz každý x den';
$l["sendToAddresses"]='Pošli mail na následující adresy';
$l["addressesLabel"]= 'Pošli mail na následující adresy (odděleno čárkou)';
$l["addressesLabelOptional"]= '(volitelné) Pošli mail na následující adresy (Pošli mail na následující adresy)';
$l["reason"]= 'Zpráva';
$l["allfollowingrules"]= 'které odpovídají následujícím podmínkám';
$l["somefollowingrules"]= 'které odpovídají jedné z následujících podmínek';
$l["allmessages"]= 'pro všechny příchozí zprávy';
$l["disablefilter"]= 'Zakaž filtr';
$l["newsieverule"]= 'Nové pravidlo';
$l["checksieveerror"]= 'Chyba při kontrole podpory Sieve';
$l["erroremptygrids"]= 'Jedno nebo více polí jsou prázdné.';
$l["errorineditmode"]= 'Právě edituješ!\n Nejprve prosím dokonči tuto akci.';
$l["subject"]= 'předmět';
$l["from"]= 'odesílatel';
$l["to"]= 'příjemce';
$l["size"]= 'velikost';
$l["contains"]= 'obsahuje';
$l["notcontains"]= 'neobsahuje';
$l["is"]= 'odpovídá';
$l["notis"]= 'neodpovídá';
$l["exists"]= 'existuje';
$l["notexists"]= 'neexistuje';
$l["fileinto"]= 'Přesuň email do adresáře';
$l["fileintoLabel"]= 'Přesuň email do vybraného adresáře';
$l["copyto"]= 'Kopíruj email do adresáře';
$l["copytoLabel"]= 'Kopíruj email do vybraného adresáře';
$l["redirect"]= 'Přepošli na';
$l["redirect_to"]= 'Kopíruj na email';
$l["vacation"]= 'Dovolená';
$l["reject"]= 'Odmítni se zprávou';
$l["toFolder"]= 'Do adresáře';
$l["discard"]= 'Zruš';
$l["stop"]= 'Konec';
$l["under"]= 'Méně než';
$l["over"]= 'Více než';
$l["disabled"]= 'Zakázáno';
$l["subjectcontainsnot"]= 'Předmět neobsahuje';
$l["fromcontainsnot"]= 'Odesílatel neobsahuje';
$l["tocontainsnot"]= 'Příjemce neobsahuje';
$l["subjectcontains"]= 'Předmět obsahuje';
$l["fromcontains"]= 'Odesílatel obsahuje';
$l["tocontains"]= 'Příjemce obsahuje';
$l["subjectexistsnot"]= 'Předmět neexistuje';
$l["fromexistsnot"]= 'Odesílatel neexistuje';
$l["toexistsnot"]= 'Příjemce neexistuje';
$l["subjectexists"]= 'Předmět existuje';
$l["fromexists"]= 'Odesílatel existuje';
$l["toexists"]= 'Příjemce existuje';
$l["markedasspam"]= 'Označeno jako SPAM';
$l["sizesmallerthan"]= 'Velikost je menší než';
$l["sizebiggerthan"]= 'Velikost je větší než';
$l["errorshowtext"]= 'Chyba při zobrazování testovacího řádku';
$l["sendcopyto"]= 'Přepošli kopii na ';
$l["forwardto"]= 'Přepošli na ';
$l["vacsendevery"]= 'Odpověz každé(ý)';
$l["vacsendevery2"]= 'dny (den) ';
$l["vacAlsoMailTo"]= 'Also email message to';
$l["vacationmessage"]= 'Zpráva:';
$l["refusewithmesssage"]= 'Odmítni se zprávou:';
$l["spamflag"]= 'značka SPAMu';
$l["custom"]= 'Volitelné';
$l["custommailheader"]= 'Hlavička mailu:';
$l["replyToMessage"]='Odpověz na email';
$l["subjectequals"]= 'Předmět odpovídá';
$l["subjectequalsnot"]= 'Předmět neodpovídá';
$l["fromequals"]= 'Od odpovídá';
$l["fromequalsnot"]= 'Od neopovídá';
$l["toequals"]= 'Komu odpovídá';
$l["toequalsnot"]= 'Komu neodpovídá';
$l['name']='Sieve';
$l['description']='Spravuj Sieve filtrovací pravidla ';
$l['active']='aktivní';
$l['standardvacation']='Standardní vacation pravidlo';
$l['standardvacationmessage']='Jsem na dovolené';

$l['setAction']='Nastav akci';
$l['setFilter']='nastav podmínku';
$l['sievePort']='Sieve filter číslo portu';
$l['useTLS']='Použij bezpečné spojení (Sieve) pro emailové filtry';
$l['cmdSaveChanges']='Ulož změny';
$l['pleaseAddCriterium']='Prosím klikni na \'Přidat\' pro přidání podmínky';
$l['pleaseAddAction']='Prosím klikni na \'Přidat\' pro přidání akce';
$l['meetingTheseCriteria']='odpovídá následujícím podmínkám';
$l['pleaseSelectOne']='Vyber si prosím';
$l['vacationStart']='První den pro tuto zprávu';
$l['vacationEnd']='Poslední den pro tuto';

$l['activateFilter']='Aktivuj tento filtr';
$l['active']='Aktivní';

==> groupoffice-com-4.1.7.tar.gz: groupoffice-com-4.1.7/modules/sieve/language/cs.php <==
<?php


$l["name"]= 'Sieve';
$l["scriptname"]= 'Jméno skriptu';
$l["index"]= 'Index';
$l["test"]= 'Test';
$l["not"]= 'Není';
$l["type"]= 'Typ';
$l["arg"]= 'Argument';
$l["arg1"]= 'Argument1';
$l["arg2"]= 'Argument2';
$l["copy"]= 'Kopie';
$l["target"]= 'Cíl';
$l["sieverules"]= 'Pravidla';
$l["activatedrules"]= 'Aktivní pravidla';
$l["field"]= 'Pole';
$l["operator"]= 'Operátor';
$l["rules"]= 'Zpráva';
$l["actions"]= 'Akce';
$l["editsieve"]= 'Edituj pravidlo';
$l["action"]= 'Akce';
$l["ruletext"]= 'Pro příchozí zprávy';
$l["actiontext"]= '...vykonej následující akce';
$l["clear"]= 'Vyčisti';
$l["active"]= 'Aktivuj';
$l["activate"]= 'Aktivuj sadu filtrů';
$l["filterset"]= 'Sada filtrů:';
$l["days"]= 'Odpověz každý x den';
$l["sendToAddresses"]='Pošli mail na následující adresy';
$l["addressesLabel"]= 'Pošli mail na následující adresy (odděleno čárkou)';
$l["addressesLabelOptional"]= '(volitelné) Pošli mail na následující adresy (Pošli mail na následující adresy)';
$l["reason"]= 'Zpráva';
$l["allfollowingrules"]= 'které odpovídají následujícím podmínkám';
$l["somefollowingrules"]= 'které odpovídají jedné z následujících podmínek';
$l["allmessages"]= 'pro všechny příchozí zprávy';
$l["disablefilter"]= 'Zakaž filtr';
$l["newsieverule"]= 'Nové pravidlo';
$l["checksieveerror"]= 'Chyba při kontrole podpory Sieve';
$l["erroremptygrids"]= 'Jedno nebo více polí jsou prázdné.';
$l["errorineditmode"]= 'Právě edituješ!\n Nejprve prosím dokonči tuto akci.';
$l["subject"]= 'předmět';
$l["from"]= 'odesílatel';
$l["to"]= 'příjemce';
$l["size"]= 'velikost';
$l["contains"]= 'obsahuje';
$l["notcontains"]= 'neobsahuje';
$l["is"]= 'odpovídá';
$l["notis"]= 'neodpovídá';
$l["exists"]= 'existuje';
$l["notexists"]= 'neexistuje';
$l["fileinto"]= 'Přesuň email do adresáře';
$l["fileintoLabel"]= 'Přesuň email do vybraného adresáře';
$l["copyto"]= 'Kopíruj email do adresáře';
$l["copytoLabel"]= 'Kopíruj email do vybraného adresáře';
$l["redirect_to"]= 'Přepošli na';
$l["redirect_copy_to"]= 'Přepošli kopie na';
$l["vacation"]= 'Dovolená';
$l["reject"]= 'Odmítni se zprávou';
$l["toFolder"]= 'Do adresáře';
$l["discard"]= 'Zruš';
$l["stop"]= 'Konec';
$l["under"]= 'Méně než';
$l["over"]= 'Více než';
$l["disabled"]= 'Zakázáno';
$l["subjectcontainsnot"]= 'Předmět neobsahuje';
$l["fromcontainsnot"]= 'Odesílatel neobsahuje';
$l["tocontainsnot"]= 'Příjemce neobsahuje';
$l["subjectcontains"]= 'Předmět obsahuje';
$l["fromcontains"]= 'Odesílatel obsahuje';
$l["tocontains"]= 'Příjemce obsahuje';
$l["subjectexistsnot"]= 'Předmět neexistuje';
$l["fromexistsnot"]= 'Odesílatel neexistuje';
$l["toexistsnot"]= 'Příjemce neexistuje';
$l["subjectexists"]= 'Předmět existuje';
$l["fromexists"]= 'Odesílatel existuje';
$l["toexists"]= 'Příjemce existuje';
$l["markedasspam"]= 'Označeno jako SPAM';
$l["sizesmallerthan"]= 'Velikost je menší než';
$l["sizebiggerthan"]= 'Velikost je větší než';
$l["errorshowtext"]= 'Chyba při zobrazování testovacího řádku';
$l["sendcopyto"]= 'Pošli kopii na ';
$l["forwardto"]= 'Přepošli na ';
$l["vacsendevery"]= 'Odpověz každé(ý)';
$l["vacsendevery2"]= 'dny (den) ';
$l["vacAlsoMailTo"]= 'Also email message to';
$l["vacationmessage"]= 'Zpráva:';
$l["refusewithmesssage"]= 'Odmítni se zprávou:';
$l["spamflag"]= 'značka SPAMu';
$l["custom"]= 'Volitelné';
$l["custommailheader"]= 'Hlavička mailu:';
$l["replyToMessage"]='Odpověz na email';
$l["subjectequals"]= 'Předmět odpovídá';
$l["subjectequalsnot"]= 'Předmět neodpovídá';
$l["fromequals"]= 'Od odpovídá';
$l["fromequalsnot"]= 'Od neopovídá';
$l["toequals"]= 'Komu odpovídá';
$l["toequalsnot"]= 'Komu neodpovídá';
$l['name']='Sieve';
$l['description']='Spravuj Sieve filtrovací pravidla ';
$l['active']='aktivní';
$l['standardvacation']='Standardní vacation pravidlo';
$l['standardvacationmessage']='Jsem na dovolené';

$l['setAction']='Nastav akci';
$l['setFilter']='nastav podmínku';
$l['sievePort']='Sieve filter číslo portu';
$l['useTLS']='Použij bezpečné spojení (Sieve) pro emailové filtry';
$l['cmdSaveChanges']='Ulož změny';
$l['pleaseAddCriterium']='Prosím klikni na \'Přidat\' pro přidání podmínky';
$l['pleaseAddAction']='Prosím klikni na \'Přidat\' pro přidání akce';
$l['meetingTheseCriteria']='odpovídá následujícím podmínkám';
$l['pleaseSelectOne']='Vyber si prosím';
$l['vacationStart']='První den pro tuto zprávu';
$l['vacationEnd']='Poslední den pro tuto';

$l['activateFilter']='Aktivuj tento filtr';
$l['active']='Aktivní';
$l['sieveWarning']="Jetliže IMAP server podporuje filtry Sieve, je doporučeno jejich použití. Prosím vyzkoušejte 'Sieve filtry' záložku.";
$l['setRead']='Označ zprávu jako přečtenou';
